==> static-compat-qt6-base-6.8.0-1-x86_64.pkg.tar.zst: usr/static-compat/include/qt6/QtCore/qtcore-config.h <==
#define QT_FEATURE_clock_monotonic -1

#define QT_FEATURE_cxx11_future -1

#define QT_FEATURE_cxx17_filesystem 1

#define QT_FEATURE_glib 1

#define QT_FEATURE_inotify 1

#define QT_FEATURE_std_atomic64 1

#define QT_FEATURE_mimetype 1

#define QT_FEATURE_regularexpression 1

#define QT_FEATURE_sharedmemory 1

#define QT_FEATURE_shortcut 1

#define QT_FEATURE_systemsemaphore 1

#define QT_FEATURE_xmlstream 1

#define QT_FEATURE_cpp_winrt -1

#define QT_FEATURE_xmlstreamreader 1

#define QT_FEATURE_xmlstreamwriter 1

#define QT_FEATURE_textdate 1

#define QT_FEATURE_datestring 1

#define QT_FEATURE_process 1

#define QT_FEATURE_processenvironment 1

#define QT_FEATURE_temporaryfile 1

#define QT_FEATURE_library 1

#define QT_FEATURE_settings 1

#define QT_FEATURE_filesystemwatcher 1

#define QT_FEATURE_filesystemiterator 1

#define QT_FEATURE_itemmodel 1

#define QT_FEATURE_proxymodel 1

#define QT_FEATURE_sortfilterproxymodel 1

#define QT_FEATURE_identityproxymodel 1

#define QT_FEATURE_transposeproxymodel 1

#define QT_FEATURE_concatenatetablesproxymodel 1

#define QT_FEATURE_stringlistmodel 1

#define QT_FEATURE_translation 1

#define QT_FEATURE_easingcurve 1

#define QT_FEATURE_animation 1

#define QT_FEATURE_gestures 1

#define QT_FEATURE_jalalicalendar 1

#define QT_FEATURE_islamiccivilcalendar 1

#define QT_FEATURE_timezone 1

#define QT_FEATURE_commandlineparser 1

#define QT_FEATURE_cborstreamreader 1

#define QT_FEATURE_cborstreamwriter 1

#define QT_FEATURE_permissions 1

#define QT_NO_CLOCK_MONOTONIC 1
#define QT_THREADSAFE_CLOEXEC 1

==> static-compat-qt6-base-6.9.3-1-x86_64.pkg.tar.zst: usr/static-compat/include/qt6/QtCore/qtcore-config.h <==
#define QT_FEATURE_clock_monotonic -1

#define QT_FEATURE_cxx11_future 1

#define QT_FEATURE_cxx17_filesystem 1

#define QT_FEATURE_glib 1

#define QT_FEATURE_inotify 1

#define QT_FEATURE_std_atomic64 1

#define QT_FEATURE_mimetype 1

#define QT_FEATURE_regularexpression 1

#define QT_FEATURE_sharedmemory 1

#define QT_FEATURE_shortcut 1

#define QT_FEATURE_systemsemaphore 1

#define QT_FEATURE_xmlstream 1

#define QT_FEATURE_cpp_winrt -1

#define QT_FEATURE_xmlstreamreader 1

#define QT_FEATURE_xmlstreamwriter 1

#define QT_FEATURE_textdate 1

#define QT_FEATURE_datestring 1

#define QT_FEATURE_process 1

#define QT_FEATURE_processenvironment 1

#define QT_FEATURE_temporaryfile 1

#define QT_FEATURE_library 1

#define QT_FEATURE_settings 1

#define QT_FEATURE_filesystemwatcher 1

#define QT_FEATURE_filesystemiterator 1

#define QT_FEATURE_itemmodel 1

#define QT_FEATURE_proxymodel 1

#define QT_FEATURE_sortfilterproxymodel 1

#define QT_FEATURE_identityproxymodel 1

#define QT_FEATURE_transposeproxymodel 1

#define QT_FEATURE_concatenatetablesproxymodel 1

#define QT_FEATURE_stringlistmodel 1

#define QT_FEATURE_translation 1

#define QT_FEATURE_easingcurve 1

#define QT_FEATURE_animation 1

#define QT_FEATURE_gestures 1

#define QT_FEATURE_jalalicalendar 1

#define QT_FEATURE_islamiccivilcalendar 1

#define QT_FEATURE_timezone 1

#define QT_FEATURE_timezone_tzdb -1

#define QT_FEATURE_commandlineparser 1

#define QT_FEATURE_cborstreamreader 1

#define QT_FEATURE_cborstreamwriter 1

#define QT_FEATURE_permissions 1

#define QT_NO_CLOCK_MONOTONIC 1
#define QT_THREADSAFE_CLOEXEC 1
